<template>
  <div class="bbsl-common-page"
       @click="commonPageClick">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam"
               :inline="true">
        <el-row :gutter="10">
          <el-col :span="6">
            <el-form-item label="水电站名称">
              <el-input clearable
                        size="mini"
                        placeholder="请输入水电站名称"
                        v-model="queryParam.params.hystName"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="工程规模">
              <el-select @change="changehyengScal"
                         size="mini"
                         v-model="queryParam.params.engScal"
                         clearable
                         placeholder="请选择工程规模">
                <el-option v-for="item in engScals"
                           :key="item.id"
                           :label="item.name"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <!-- <el-col :span="6">
            <el-form-item label="水电站代码">
              <el-input
                size="mini"
                clearable
                placeholder="请输入水电站代码"
                v-model="queryParam.params.hystCode"
              ></el-input>
            </el-form-item>
          </el-col> -->
          <el-col :span="6">
            <el-form-item label="水电站类型">
              <el-select @change="changehystType"
                         size="mini"
                         v-model="queryParam.params.hystType"
                         clearable
                         placeholder="请选择水电站类型">
                <el-option v-for="item in hystTypes"
                           :key="item.id"
                           :label="item.name"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item>
              <el-button type="primary"
                         icon="el-icon-search"
                         size="mini"
                         @click="onClickSearch">搜索</el-button>
              <el-button icon="el-icon-refresh"
                         size="mini"
                         @click="resetQuery">重置</el-button>
              <!-- <el-button type="text" @click.stop="openMore"
                >更多
                <i
                  :class="showMore ? 'el-icon-arrow-up' : 'el-icon-arrow-down'"
                ></i
              ></el-button> -->
            </el-form-item>
          </el-col>
        </el-row>
        <!-- <div class="bbsl-search-more" v-if="showMore">
          <el-row>
         
          </el-row>
        </div> -->
      </el-form>
    </div>
    <div class="bbsl-table-content"
         ref="contentPanel">
      <div class="bbsl-btn-content"
           ref="btnPanel">
        <el-button size="mini"
                   icon="el-icon-plus"
                   type="primary"
                   @click="openFormDiao">新增</el-button>
        <el-button :disabled="!multipleSelection.length"
                   size="mini"
                   icon="el-icon-delete"
                   type="danger"
                   @click="deleteSelect">删除</el-button>
      </div>
      <el-table stripe
                size="mini"
                :height="tableMaxHeight"
                @row-dblclick="handleDbClick"
                :style="{width: '100%'}"
                ref="multipleSelection"
                v-loading="loading"
                border
                :data="tableData"
                :row-key="getRowKey"
                @selection-change="handleSelectionChange"
                :header-cell-style="{'text-align': 'center'}"
                :cell-style="{'text-align': 'center'}">
        <el-table-column type="selection"
                         width="55"
                         :reserve-selection="true"></el-table-column>
        <el-table-column type="index"
                         width="55"
                         label="序号"></el-table-column>
        <el-table-column min-width="100"
                         sortable
                         prop="hystCode"
                         label="水电站代码"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="130"
                         sortable
                         prop="hystName"
                         label="水电站名称"
                         show-overflow-tooltip></el-table-column>

        <el-table-column min-width="140"
                         sortable
                         prop="hystTypeName"
                         label="水电站类型"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="140"
                         sortable
                         prop="totInsCap"
                         label="总装机容量(kW)"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="160"
                         sortable
                         prop="engScalName"
                         label="工程规模"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column label="操作"
                         min-width="160">
          <template #default="scope">
            <el-dropdown split-button
                         @click="relationStation(scope.row)"
                         @command="relationUpdate(scope.row)">
              关联测站
              <el-dropdown-menu slot="dropdown">
                <el-dropdown-item command="waterStation">关联视频点位</el-dropdown-item>

              </el-dropdown-menu>
            </el-dropdown>

          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel"
                     align="right"
                     class="bbsl-pagination"
                     background
                     @size-change="handleSizeChange"
                     @current-change="handleCurrentChange"
                     :current-page="queryParam.pageBean.page"
                     :page-sizes="[20, 30,40,50]"
                     :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper"
                     :total="total"></el-pagination>
    </div>
    <form-dialog v-if="showFormDia"
                 @closeFormDiao="closeFormDiao"
                 @refList="getDateList"
                 :showFormDia="showFormDia"
                 :title="title"
                 :pId="pId"></form-dialog>
    <hysRelation v-if="showFormDias"
                 @closeFormDiaos="closeFormDiaos"
                 :showFormDias="showFormDias"
                 @refList="getDateList"
                 :relation="relation"
                 :rowId="rowId"></hysRelation>
    <!-- 关联测站弹框 -->
    <hysStresRelation v-if="StshowFormDias"
                      @closeStshowForm="closeStshowForm"
                      :StshowFormDias="StshowFormDias"
                      @refList="getDateList"
                      :relation="relation"
                      :rowId="rowId"></hysStresRelation>
  </div>
</template>
<script>
import hysRelation from './components/hysRelation.vue'
import FormDialog from './components/hystForm-dialog.vue'
import hystManager from '@/api/reservoirManagement/hystManager.js'
import hysStresRelation from './components/hysStresRelation.vue'
import req from '@/request.js'
import { TableMixin } from '@/mixins/tableMixin'
export default {
  name: 'hystManager',
  components: {
    FormDialog,
    hysRelation,
    hysStresRelation
  },
  mixins: [TableMixin],
  data () {
    return {
      loading: false,
      relation: '',//关联参数
      reSets: [{ name: '关联测站', value: 'relationStation', id: '1' }, { name: '关联监控点', value: 'relationUpdate', id: '2' }],
      rowId: '',
      multipleSelection: [], // 复选框
      queryParam: {
        pageBean: {
          pageSize: 20,
          page: 1,
        },
        params: {
          hystCode: null, //水电站代码
          hystName: null, //水电站名称
          hystType: null, //水电站类型（参考字典）
          engScal: null, //工程规模
        },
      },
      showFormDias: false,
      StshowFormDias: false,
      total: 0,
      title: '',
      showFormDia: false,
      tableData: [],
      pId: '',
      hystTypes: [], //水电站类型
      engScals: [], //工程规模
    }
  },
  created () {
    this.getDateList()
    this.getSysDict()
  },
  methods: {
    relationUpdate (row) {//打开监控关联
      this.row = row;
      this.relation = this.row.hystCode;
      this.rowId = this.row.id;
      this.showFormDias = true;
    },
    relationStation (row) {//打开测站关联
      this.row = row;
      this.relation = this.row.hystCode;
      this.rowId = this.row.id;
      this.StshowFormDias = true;
    },
    closeFormDiaos () {//关闭监控关联
      this.showFormDias = false;
      this.getDateList()
    },
    closeStshowForm () {//关闭测站关联
      this.StshowFormDias = false;
      this.getDateList()
    },
    changehyengScal (val) {
      if (val) {
        this.queryParam.params.engScal = val
        this.getDateList()
      } else {
        this.queryParam.params.engScal = null
      }
    },
    changehystType (val) {
      if (val) {
        this.queryParam.params.hystType = val
        this.getDateList()
      } else {
        this.queryParam.params.hystType = null
      }
    },
    //获取字典数据
    getSysDict () {
      let portal = window.context.portal
      return new Promise((resolve, reject) => {
        req.post(portal + '/sys/sysDictionary/v1/queryAllDictItems').then(
          (response) => {
            resolve(response.data)
            this.hystTypes = response.data.sdzlx //水电站类型
            this.engScals = response.data.gcgm //工程规模
            this.getDateList()
          },
          (error) => {
            reject(error)
          }
        )
      })
    },
    getDateList () {
      this.loading = true
      this.tableData = []
      hystManager.ListGet(this.queryParam, (res) => {
        this.total = res.value.total;
        for (let i = 0; i < this.hystTypes.length; i++) {
          for (let j = 0; j < res.value.rows.length; j++) {
            if (this.hystTypes[i].value === res.value.rows[j].hystType) {
              res.value.rows[j].hystTypeName = this.hystTypes[i].name
            } else {
            }
          }
        }
        for (let i = 0; i < this.engScals.length; i++) {
          for (let j = 0; j < res.value.rows.length; j++) {
            if (this.engScals[i].value === res.value.rows[j].engScal) {
              res.value.rows[j].engScalName = this.engScals[i].name
            } else {

            }
          }
        }
        this.tableData = res.value.rows
        this.loading = false
      })
    },
    openFormDiao () {
      this.title = '新增'
      this.showFormDia = true
    },
    closeFormDiao () {
      this.showFormDia = false
      this.getDateList()
    },
    handleSizeChange (val) {
      this.queryParam.pageBean.pageSize = val
      this.getDateList()
    },
    handleCurrentChange (val) {
      this.queryParam.pageBean.page = val
      this.getDateList()
    },
    // // 修改
    handleUpdate (row) {
      this.title = '修改'
      this.pId = row.id
      this.showFormDia = true
    },
    handleSelectionChange (val) {
      this.multipleSelection = val.map((item) => {
        return item.id
      })
    },
    // // 指定一个key标识这一行的数据
    getRowKey (row) {
      return row.id
    },
    // // 批量删除
    deleteSelect () {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          hystManager
            .remove(this.multipleSelection, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                // this.multipleSelection = [];
                this.$refs.multipleSelection.clearSelection()
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    /** 删除按钮操作 */
    handleDelete (row) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          hystManager
            .remove(row.id, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    // // 点击查询
    onClickSearch () {
      this.queryParam.pageBean.page = 1
      this.getDateList()
    },
    // 重置
    resetQuery () {
      this.queryParam.params = {}
      this.onClickSearch()
    },
  },
}
</script>
<style lang="scss" scoped>
.btn-content {
  display: flex;
}
.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}
.el-select-dropdown__item {
  color: #9a9a9a !important;
}
.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}
.btn-content :first-child {
  margin: 0 0 0 0 !important;
}
// ::v-deep .el-table__body-wrapper::-webkit-scrollbar {
//   width: 6px;
//   height: 15px;
// }
.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}
::-webkit-scrollbar {
  background: #fff !important;
}
.bbsl-pagination {
  bottom: 10px !important;
}
</style>
